// Version Resource Script
//

#include <windows.h>

//
// Icon
// 
//   The icon whose name or resource ID is lexigraphically first, is used
//   as the application's icon.
//

app                      ICON    DISCARDABLE     "trane.ico"

