 
////////////////////////////////////////////////////////////////////////
// This file is part of the SndObj library
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
//
// Copyright (c)Victor Lazzarini, 1997-2004
// See License.txt for a disclaimer of all warranties
// and licensing information

////////////////////////////////////////////////
// TpTz.h: interface for the TpTz class
//        two-pole two-zero filter.
//
///////////////////////////////////////////////

#ifndef _TPTZ_H
#define _TPTZ_H

#include "Filter.h"

class TpTz: public Filter {

 protected:


  double m_a1;
  double m_a2;


 public:

  TpTz();
  TpTz(double a, double a1, double a2,
       double b1, double b2, SndObj* input,
       int vecsize=DEF_VECSIZE, float sr=DEF_SR);

  ~TpTz();

  void
    SetParam(double a, double a1, double a2,
	     double b1, double b2){
    m_a = a;
    m_a1 = a1;
    m_a2 = a2;
    m_b2 = b2;
    m_b1 = b1;
  }

  int Set(char* mess, float value);

  short DoProcess();

};

#endif










