 
////////////////////////////////////////////////////////////////////////
// This file is part of the SndObj library
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
//
// Copyright (c)Victor Lazzarini, 1997-2004
// See License.txt for a disclaimer of all warranties
// and licensing information

#ifndef _PAN_H 
#define _PAN_H 
#include "SndObj.h"
#include <math.h>


const double  squrt2o2 = sqrt(2.) / 2.; 

class Pan : public SndObj{

 protected:

  SndObj*       m_channel;
  float         m_pan;
  int           m_res;
  float*        m_panpos;
  SndObj*        m_inputpan;
  inline float Panning(float pan, int chan);
   
 public:
   
  SndObj*  left;
  SndObj*  right;
  Pan();                            
  Pan(float pan, SndObj* InObj, SndObj* InPan = 0, int res=1024, int vecsize=DEF_VECSIZE, float sr=DEF_SR);
  ~Pan();
  
  void  SetPan(float pan, SndObj* InPan = 0){
    m_pan = pan;
    m_inputpan = InPan;
  }
  int Set(char* mess, float value);
  int Connect(char* mess, void* input);
	
  short DoProcess();          
  char* ErrorMessage();
};


#endif
